=================
Project internals
=================

Documentation for people working on Django MongoDB Backend itself. This is the
place to go if you'd like to help improve Django MongoDB Backend or learn about
how the project is managed.

.. _issue-tracker:

Issue tracker
=============

To report a bug or to request a new feature in Django MongoDB Backend, please
open an issue in our issue tracker, JIRA:

1. Create a `JIRA account <https://jira.mongodb.org/>`_.

2. Navigate to the `Python Integrations project
   <https://jira.mongodb.org/projects/INTPYTHON/>`_.

3. Click **Create Issue**. Please provide as much information as possible about
   the issue and the steps to reproduce it.

Bug reports in JIRA for this project can be viewed by everyone.
